@@ -1,32 +1,20 @@
 from django.apps import apps, AppConfig
-from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.template import TemplateDoesNotExist
 from django.template.backends.base import BaseEngine
 from django.utils.module_loading import import_string
-
-from .defaults import DEFAULT_OPTIONS
-from .template import MakoTemplateLoader, MakoTemplateAdapter
-from .registry import register_dmp_app, ensure_dmp_app, is_dmp_app
-from .provider.runner import init_providers
-from .util import DMP_INSTANCE_KEY, DMP_OPTIONS
-
 from mako.template import Template
 
+from .template import MakoTemplateLoader, MakoTemplateAdapter
+
 import itertools
 import os
 import os.path
 import re
-try:
-    # python 3.4+
-    pass
-except ImportError:
-    # python <= 3.4
-    pass
 
 
 # Following Django's lead, hard coding the CSRF processor
-_builtin_context_processors = (
+BUILTIN_CONTEXT_PROCESSORS = (
     'django_mako_plus.context_processors.csrf',
 )
 
@@ -47,42 +35,24 @@ class MakoTemplates(BaseEngine):
     '''
     def __init__(self, params):
         '''Constructor'''
-        # start with the default options
-        DMP_OPTIONS.update(DEFAULT_OPTIONS)
-
-        # pop the settings.py options into the DMP optionsRUNTIME_TEMPLATE_IMPORTS
+        # ensure DMP is listed as an app (common install error)
         try:
-            DMP_OPTIONS.update(params.pop('OPTIONS'))
-        except KeyError:
-            raise ImproperlyConfigured('The Django Mako Plus template OPTIONS were not set up correctly in settings.py.  Please ensure the OPTIONS is set in the template setup.')
+            self.dmp = apps.get_app_config('django_mako_plus')
+        except LookupError:
+            raise ImproperlyConfigured("`django_mako_plus` must be listed in INSTALLED_APPS before it can be used")
 
-        # django_mako_plus is always available in templates
-        DMP_OPTIONS['RUNTIME_TEMPLATE_IMPORTS'] = [ 'import django_mako_plus' ]
-        DMP_OPTIONS['RUNTIME_TEMPLATE_IMPORTS'].extend(DMP_OPTIONS['DEFAULT_TEMPLATE_IMPORTS'])
-
-        # cache our instance in the util module for get_dmp_instance
-        # this is a bit of a hack, but it makes calling utility methods possible and efficient
-        DMP_OPTIONS[DMP_INSTANCE_KEY] = self
+        # cache for our template loaders
         self.template_loaders = {}
 
-        # super constructor
-        super(MakoTemplates, self).__init__(params)
-
         # set up the context processors
         context_processors = []
-        for processor in itertools.chain(_builtin_context_processors, DMP_OPTIONS['CONTEXT_PROCESSORS']):
+        for processor in itertools.chain(BUILTIN_CONTEXT_PROCESSORS, self.dmp.options['CONTEXT_PROCESSORS']):
             context_processors.append(import_string(processor))
         self.template_context_processors = tuple(context_processors)
 
-        # set up the static file providers
-        init_providers()
-
-        # add a template renderer for each app in the project directory
-        if DMP_OPTIONS['APP_DISCOVERY'] != 'none' and DMP_OPTIONS['APP_DISCOVERY'] is not False:
-            for config in apps.get_app_configs():
-                if DMP_OPTIONS['APP_DISCOVERY'] == 'all' or os.path.samefile(os.path.dirname(config.path), settings.BASE_DIR):
-                    register_dmp_app(config)
-
+        # super constructor
+        params.pop('OPTIONS', None)   # the super doesn't like OPTIONS in there
+        super(MakoTemplates, self).__init__(params)
 
 
     def from_string(self, template_code):
@@ -90,7 +60,8 @@ class MakoTemplates(BaseEngine):
         Compiles a template from the given string.
         This is one of the required methods of Django template engines.
         '''
-        mako_template = Template(template_code, imports=DMP_OPTIONS['RUNTIME_TEMPLATE_IMPORTS'], input_encoding=DMP_OPTIONS['DEFAULT_TEMPLATE_ENCODING'])
+        dmp = apps.get_app_config('django_mako_plus')
+        mako_template = Template(template_code, imports=dmp.template_imports, input_encoding=dmp.options['DEFAULT_TEMPLATE_ENCODING'])
         return MakoTemplateAdapter(mako_template)
 
 
@@ -107,10 +78,11 @@ class MakoTemplates(BaseEngine):
         Template rendering can be limited to a specific def/block within the template
         by specifying `#def_name`, e.g. `myapp/mytemplate.html#myblockname`.
         '''
+        dmp = apps.get_app_config('django_mako_plus')
         match = RE_TEMPLATE_NAME.match(template_name)
         if match is None or match.group(1) is None or match.group(3) is None:
             raise TemplateDoesNotExist('Invalid template_name format for a DMP template.  This method requires that the template name be in app_name/template.html format (separated by slash).')
-        if not is_dmp_app(match.group(1)):
+        if not dmp.is_registered_app(match.group(1)):
             raise TemplateDoesNotExist('Not a DMP app, so deferring to other template engines for this template')
         return self.get_template_loader(match.group(1)).get_template(match.group(3), def_name=match.group(5))
 
@@ -149,7 +121,9 @@ class MakoTemplates(BaseEngine):
 
         # if create=False, the loader must already exist in the cache
         if not create:
-            ensure_dmp_app(app)
+            dmp = apps.get_app_config('django_mako_plus')
+            if not dmp.is_registered_app(app):
+                raise ValueError("{} is not registered with DMP [hint: check urls.py for include('django_mako_plus.urls')].".format(app))
 
         # return the template by path
         return self.get_template_loader_for_path(path, use_cache=True)
