@@ -1,21 +1,27 @@
+from django.apps import apps
 from django.core.management.base import BaseCommand, CommandError
 from django.conf import settings
-
-from django_mako_plus.util import DMP_OPTIONS
-from django_mako_plus.registry import get_dmp_apps
+from django_mako_plus.management.mixins import DMPCommandMixIn
 
 import os, os.path, shutil
 
 
 
 
-class Command(BaseCommand):
-    args = ''
+class Command(DMPCommandMixIn, BaseCommand):
     help = 'Removes compiled template cache folders in your DMP-enabled app directories.'
     can_import_settings = True
 
 
     def add_arguments(self, parser):
+        super().add_arguments(parser)
+
+        parser.add_argument(
+            'appname',
+            type=str,
+            nargs='*',
+            help='The name of one or more DMP apps. If omitted, all DMP apps are processed.'
+        )
         parser.add_argument(
             '--trial-run',
             action='store_true',
@@ -23,30 +29,13 @@ class Command(BaseCommand):
             default=False,
             help='Display the folders that would be removed without actually removing them.'
         )
-        parser.add_argument(
-            '--verbose',
-            action='store_true',
-            dest='verbose',
-            default=False,
-            help='Set verbosity to level 3 (see --verbosity).'
-        )
-        parser.add_argument(
-            '--quiet',
-            action='store_true',
-            dest='quiet',
-            default=False,
-            help='Set verbosity to level 0, which silences all messages (see --verbosity).'
-        )
 
 
     def handle(self, *args, **options):
+        dmp = apps.get_app_config('django_mako_plus')
+
         # save the options for later
-        self.options = options
-        if self.options['verbose']:
-            self.options['verbosity'] = 3
-        if self.options['quiet']:
-            self.options['verbosity'] = 0
-        if self.options['trial_run']:
+        if options.get('trial_run'):
             self.message("Trial run: dmp_cleanup would have deleted the following folders:", level=1)
 
         # ensure we have a base directory
@@ -58,23 +47,28 @@ class Command(BaseCommand):
             raise CommandError('Your settings.py file is missing the BASE_DIR setting.')
 
         # check each dmp-enabled app
-        for config in get_dmp_apps():
+        for config in dmp.get_registered_apps():
             self.message('Cleaning up app: {}'.format(config.name), level=1)
             for subdir in ( 'templates', 'scripts', 'styles' ):
-                cache_dir = os.path.join(config.path, subdir, DMP_OPTIONS['TEMPLATES_CACHE_DIR'])
-                if os.path.exists(cache_dir):
-                    self.message('Removing {}'.format(pretty_relpath(cache_dir, settings.BASE_DIR)), level=2)
-                    if not self.options['trial_run']:
-                        shutil.rmtree(cache_dir)
-                else:
-                    self.message('Skipping {} because it does not exist'.format(pretty_relpath(cache_dir, settings.BASE_DIR)), level=2)
+                self.deep_clean(os.path.join(config.path, subdir), options.get('trial_run'))
 
+    def deep_clean(self, path, trial_run):
+        dmp = apps.get_app_config('django_mako_plus')
 
-    def message(self, msg, level):
-        '''Print a message to the console'''
-        # verbosity=1 is the default if not specified in the options
-        if self.options['verbosity'] >= level:
-            print(msg)
+        # clean this directory
+        cache_dir = os.path.join(path, dmp.options['TEMPLATES_CACHE_DIR'])
+        if os.path.exists(cache_dir):
+            self.message('Removing {}'.format(pretty_relpath(cache_dir, settings.BASE_DIR)), level=2)
+            if not trial_run:
+                shutil.rmtree(cache_dir)
+        else:
+            self.message('Skipping {} because it does not exist'.format(pretty_relpath(cache_dir, settings.BASE_DIR)), level=2)
+
+        # recurse to subdirectories
+        for name in os.listdir(path):
+            subpath = os.path.join(path, name)
+            if os.path.isdir(subpath):
+                self.deep_clean(subpath, trial_run)
 
 
 
