@@ -1,8 +1,8 @@
-from django.core.management.base import BaseCommand, CommandError
+from django.apps import apps
+from django.core.management.base import CommandError
+from django.contrib.staticfiles.management.commands.collectstatic import Command as CollectStaticCommand
 from django.conf import settings
-
-from django_mako_plus.util import DMP_OPTIONS
-from django_mako_plus.registry import get_dmp_apps
+from django_mako_plus.management.mixins import DMPCommandMixIn
 
 import os, os.path, shutil, fnmatch
 
@@ -38,41 +38,16 @@ class Rule(object):
         return 0
 
 
-INITIAL_RULES = (
-    # files are included by default
-    Rule('*',                                    level=None, filetype=TYPE_FILE,      score=1),
-    # files at the app level are skipped
-    Rule('*',                                    level=0,    filetype=TYPE_FILE,      score=-2),
-    # directories are recursed by default
-    Rule('*',                                    level=None, filetype=TYPE_DIRECTORY, score=1),
-    # directories at the app level are skipped
-    Rule('*',                                    level=0,    filetype=TYPE_DIRECTORY, score=-2),
-
-    # media, scripts, styles directories are what we want to copy
-    Rule('media',                                level=0,    filetype=TYPE_DIRECTORY, score=6),
-    Rule('scripts',                              level=0,    filetype=TYPE_DIRECTORY, score=6),
-    Rule('styles',                               level=0,    filetype=TYPE_DIRECTORY, score=6),
-
-    # ignore the template cache directories
-    Rule(DMP_OPTIONS['TEMPLATES_CACHE_DIR'],     level=None, filetype=TYPE_DIRECTORY, score=-3),
-    # ignore python cache directories
-    Rule('__pycache__',                          level=None, filetype=TYPE_DIRECTORY, score=-3),
-    # ignore compiled python files
-    Rule('*.pyc',                                level=None, filetype=TYPE_FILE,      score=-3),
-    # ignore all cssm and jsm files (these are rendered at runtime, so not static)
-    Rule('*.cssm',                               level=None, filetype=TYPE_FILE,      score=-3),
-    Rule('*.jsm',                                level=None, filetype=TYPE_FILE,      score=-3),
-)
 
 
 
-class Command(BaseCommand):
-    args = ''
+class Command(DMPCommandMixIn, CollectStaticCommand):
     help = 'Collects static files, such as media, scripts, and styles, to a common directory root. This is done to prepare for deployment.'
     can_import_settings = True
 
-
     def add_arguments(self, parser):
+        super().add_arguments(parser)
+
         parser.add_argument(
             '--overwrite',
             action='store_true',
@@ -80,20 +55,6 @@ class Command(BaseCommand):
             default=False,
             help='Overwrite existing files in the directory when necessary.'
         )
-        parser.add_argument(
-            '--verbose',
-            action='store_true',
-            dest='verbose',
-            default=False,
-            help='Set verbosity to level 3 (see --verbosity).'
-        )
-        parser.add_argument(
-            '--quiet',
-            action='store_true',
-            dest='quiet',
-            default=False,
-            help='Set verbosity to level 0, which silences all messages (see --verbosity).'
-        )
         parser.add_argument(
             '--no-minify',
             action='store_true',
@@ -127,12 +88,8 @@ class Command(BaseCommand):
 
 
     def handle(self, *args, **options):
-        # save the options for later
+        dmp = apps.get_app_config('django_mako_plus')
         self.options = options
-        if self.options['verbose']:
-            self.options['verbosity'] = 3
-        if self.options['quiet']:
-            self.options['verbosity'] = 0
 
         # ensure we have a base directory
         try:
@@ -147,7 +104,7 @@ class Command(BaseCommand):
         # if dest_root doesn't start with a /, it goes relative to the BASE_DIR
         try:
             dest_root = os.path.join(os.path.abspath(settings.BASE_DIR), settings.STATIC_ROOT)
-            if os.path.exists(dest_root) and not self.options['overwrite']:
+            if os.path.exists(dest_root) and not self.options.get('overwrite'):
                 raise CommandError('The destination directory for static files (%s) already exists. Please delete it or run this command with the --overwrite option.' % dest_root)
         except AttributeError:
             raise CommandError('Your settings.py file is missing the STATIC_ROOT setting. Exiting without collecting the static files.')
@@ -157,38 +114,55 @@ class Command(BaseCommand):
             os.makedirs(dest_root)
 
         # set up the rules
-        self.rules = list(INITIAL_RULES)
-        self.add_user_rules()
+        self.rules = self.create_rules()
 
         # go through the DMP apps and collect the static files
-        for config in get_dmp_apps():
+        for config in dmp.get_registered_apps():
             self.message('Processing app {}'.format(config.name), 1)
             self.copy_dir(config.path, os.path.abspath(os.path.join(dest_root, config.name)))
 
 
-    def message(self, msg, level, tab=0):
-        '''Print a message to the console'''
-        # verbosity=1 is the default if not specified in the options
-        if self.options['verbosity'] >= min(level, 3):
-            print('{}{}'.format('    ' * tab, msg))
-
-
-    def add_user_rules(self):
+    def create_rules(self):
         '''Adds rules for the command line options'''
+        dmp = apps.get_app_config('django_mako_plus')
+        # the default
+        rules = [
+            # files are included by default
+            Rule('*',                                    level=None, filetype=TYPE_FILE,      score=1),
+            # files at the app level are skipped
+            Rule('*',                                    level=0,    filetype=TYPE_FILE,      score=-2),
+            # directories are recursed by default
+            Rule('*',                                    level=None, filetype=TYPE_DIRECTORY, score=1),
+            # directories at the app level are skipped
+            Rule('*',                                    level=0,    filetype=TYPE_DIRECTORY, score=-2),
+
+            # media, scripts, styles directories are what we want to copy
+            Rule('media',                                level=0,    filetype=TYPE_DIRECTORY, score=6),
+            Rule('scripts',                              level=0,    filetype=TYPE_DIRECTORY, score=6),
+            Rule('styles',                               level=0,    filetype=TYPE_DIRECTORY, score=6),
+
+            # ignore the template cache directories
+            Rule(dmp.options['TEMPLATES_CACHE_DIR'],     level=None, filetype=TYPE_DIRECTORY, score=-3),
+            # ignore python cache directories
+            Rule('__pycache__',                          level=None, filetype=TYPE_DIRECTORY, score=-3),
+            # ignore compiled python files
+            Rule('*.pyc',                                level=None, filetype=TYPE_FILE,      score=-3),
+        ]
         # include rules have score of 50 because they trump all initial rules
-        for pattern in (self.options['include_dir'] or []):
+        for pattern in (self.options.get('include_dir') or []):
             self.message('Setting rule - recurse directories: {}'.format(pattern), 1)
-            self.rules.append(Rule(pattern, level=None, filetype=TYPE_DIRECTORY, score=50))
-        for pattern in (self.options['include_file'] or []):
+            rules.append(Rule(pattern, level=None, filetype=TYPE_DIRECTORY, score=50))
+        for pattern in (self.options.get('include_file') or []):
             self.message('Setting rule - include files: {}'.format(pattern), 1)
-            self.rules.append(Rule(pattern, level=None, filetype=TYPE_FILE, score=50))
+            rules.append(Rule(pattern, level=None, filetype=TYPE_FILE, score=50))
         # skip rules have score of 100 because they trump everything, including the includes from the command line
-        for pattern in (self.options['skip_dir'] or []):
+        for pattern in (self.options.get('skip_dir') or []):
             self.message('Setting rule - skip directories: {}'.format(pattern), 1)
-            self.rules.append(Rule(pattern, level=None, filetype=TYPE_DIRECTORY, score=-100))
-        for pattern in (self.options['skip_file'] or []):
+            rules.append(Rule(pattern, level=None, filetype=TYPE_DIRECTORY, score=-100))
+        for pattern in (self.options.get('skip_file') or []):
             self.message('Setting rule - skip files: {}'.format(pattern), 1)
-            self.rules.append(Rule(pattern, level=None, filetype=TYPE_FILE, score=-100))
+            rules.append(Rule(pattern, level=None, filetype=TYPE_FILE, score=-100))
+        return rules
 
 
     def copy_dir(self, source, dest, level=0):
@@ -232,7 +206,7 @@ class Command(BaseCommand):
                 self.copy_dir(source_path, dest_path, level+1)
 
             # if a regular Javscript file, run through the static file processors (scripts group)
-            elif ext == '.js' and not self.options['no_minify'] and jsmin:
+            elif ext == '.js' and not self.options.get('no_minify') and jsmin:
                 self.message('Including and minifying file with score {}: {}'.format(score, source_path), msglevel, level+1)
                 with open(source_path, encoding=encoding) as fin:
                     with open(dest_path, 'w', encoding=encoding) as fout:
@@ -241,7 +215,7 @@ class Command(BaseCommand):
 
 
             # if a CSS file, run through the static file processors (styles group)
-            elif ext == '.css' and not self.options['no_minify'] and cssmin:
+            elif ext == '.css' and not self.options.get('no_minify') and cssmin:
                 self.message('Including and minifying file with score {}: {}'.format(score, source_path), msglevel, level+1)
                 with open(source_path, encoding=encoding) as fin:
                     with open(dest_path, 'w', encoding=encoding) as fout:
@@ -267,4 +241,3 @@ def minify(text, minifier):
     if  abs(len(text) - len(minified)) > 50 or '\n' in text[:50]:
         return minified
     return text
-
