@@ -1,40 +1,25 @@
 from django.apps import apps as django_apps
 from django.conf import settings
 from django.core.management.base import BaseCommand, CommandError
-from mako.exceptions import MakoException
-from django_mako_plus.registry import get_dmp_apps, ensure_dmp_app
-from django_mako_plus.provider import create_mako_context
-from django_mako_plus.provider.runner import ProviderRun, create_factories
-from django_mako_plus.util import get_dmp_instance, split_app, DMP_OPTIONS
+from django_mako_plus.template import create_mako_context
+from django_mako_plus.provider.runner import ProviderRun, init_provider_factories
+from django_mako_plus.management.mixins import DMPCommandMixIn
 
-import glob
-import os, os.path, shutil
-import json
+import sys
+import os
+import os.path
 from collections import OrderedDict
+from datetime import datetime
 
 
-
-class Command(BaseCommand):
-    args = ''
+class Command(DMPCommandMixIn, BaseCommand):
     help = 'Removes compiled template cache folders in your DMP-enabled app directories.'
     can_import_settings = True
 
 
     def add_arguments(self, parser):
-        parser.add_argument(
-            '--verbose',
-            action='store_true',
-            dest='verbose',
-            default=False,
-            help='Set verbosity to level 3 (see --verbosity).'
-        )
-        parser.add_argument(
-            '--quiet',
-            action='store_true',
-            dest='quiet',
-            default=False,
-            help='Set verbosity to level 0, which silences all messages (see --verbosity).'
-        )
+        super().add_arguments(parser)
+
         parser.add_argument(
             '--overwrite',
             action='store_true',
@@ -56,40 +41,27 @@ class Command(BaseCommand):
         )
 
 
-    def message(self, msg, level=1):
-        '''Print a message to the console'''
-        # verbosity=1 is the default if not specified in the options
-        if self.options['verbosity'] >= level:
-            print(msg)
-
-
     def handle(self, *args, **options):
-        # save the options for later
+        dmp = django_apps.get_app_config('django_mako_plus')
         self.options = options
-        if self.options['verbose']:
-            self.options['verbosity'] = 3
-        if self.options['quiet']:
-            self.options['verbosity'] = 0
-        self.factories = create_factories('WEBPACK_PROVIDERS')
+        self.factories = init_provider_factories('WEBPACK_PROVIDERS')
 
         # ensure we have a base directory
         try:
             if not os.path.isdir(os.path.abspath(settings.BASE_DIR)):
                 raise CommandError('Your settings.py BASE_DIR setting is not a valid directory.  Please check your settings.py file for the BASE_DIR variable.')
         except AttributeError as e:
-            print(e)
             raise CommandError('Your settings.py file is missing the BASE_DIR setting.')
 
         # the apps to process
         apps = []
-        for appname in options['appname']:
-            ensure_dmp_app(appname)
+        for appname in options.get('appname'):
             apps.append(django_apps.get_app_config(appname))
         if len(apps) == 0:
-            apps = get_dmp_apps()
+            apps = dmp.get_registered_apps()
 
         # main runner for per-app files
-        if self.options['single'] is None:
+        if options.get('single') is None:
             for app in apps:
                 self.message('Searching `{}` app...'.format(app.name))
                 filename = os.path.join(app.path, 'scripts', '__entry__.js')
@@ -101,7 +73,7 @@ class Command(BaseCommand):
             for app in apps:
                 self.message('Searching `{}` app...'.format(app.name))
                 script_map.update(self.generate_script_map(app))
-            self.create_entry_file(self.options['single'], script_map, apps)
+            self.create_entry_file(options.get('single'), script_map, apps)
 
 
     def create_entry_file(self, filename, script_map, apps):
@@ -119,23 +91,34 @@ class Command(BaseCommand):
 
         filedir = os.path.dirname(filename)
         if os.path.exists(filename):
-            if self.options['overwrite']:
+            if self.options.get('overwrite'):
                 os.remove(filename)
             else:
-                raise ValueError('Refusing to destroy existing file: {} (use --overwrite option or remove the file)'.format(filename))
+                raise CommandError('Refusing to destroy existing file: {} (use --overwrite option or remove the file)'.format(filename))
+
         # create the lines of the entry file
         lines = []
         for page, scripts in script_map.items():
             require = []
-            for s in scripts:
-                if in_apps(os.path.abspath(s)):
-                    require.append('require("./{}")'.format(os.path.relpath(s, filedir)))
+            for script_path in scripts:
+                if in_apps(script_path):
+                    require.append('require("./{}")'.format(os.path.relpath(script_path, filedir)))
             if len(require) > 0:
-                lines.append('DMP_CONTEXT.appBundles["{}"] = () => {{ {}; }};'.format(page, '; '.join(require)))
-        # if we created at least one line, write the entry file
+                lines.append('DMP_CONTEXT.appBundles["{}"] = () => {{ \n        {};\n    }};'.format(page, ';\n        '.join(require)))
+
+        # if we had at least one line, write the entry file
         if len(lines) > 0:
             self.message('Creating {}'.format(os.path.relpath(filename, settings.BASE_DIR)))
             with open(filename, 'w') as fout:
+                fout.write('// Generated on {} by `{}`\n'.format(
+                    datetime.now().strftime('%Y-%m-%d %H:%M'),
+                    ' '.join(sys.argv),
+                ))
+                fout.write('// Contains links for app{}: {}\n'.format(
+                    's' if len(apps) > 1 else '',
+                    ', '.join(sorted([ app.name for app in apps ])),
+                ))
+                fout.write('\n')
                 fout.write('(context => {\n')
                 for line in lines:
                     fout.write('    {}\n'.format(line))
@@ -149,33 +132,38 @@ class Command(BaseCommand):
         dictionary with paths relative to BASE_DIR:
 
         {
-            'app/template1': [ 'scripts/template1.js', 'scripts/supertemplate1.js' ],
-            'app/template2': [ 'scripts/template2.js', 'scripts/supertemplate2.js', 'scripts/supersuper2.js' ],
+            'app/template1': [ '/abs/path/to/scripts/template1.js', '/abs/path/to/scripts/supertemplate1.js' ],
+            'app/template2': [ '/abs/path/to/scripts/template2.js', '/abs/path/to/scripts/supertemplate2.js', '/abs/path/to/scripts/supersuper2.js' ],
             ...
         }
 
         Any files or subdirectories starting with double-underscores (e.g. __dmpcache__) are skipped.
         '''
         script_map = OrderedDict()
-        template_root = os.path.join(config.path, 'templates')
+        template_root = os.path.join(os.path.relpath(config.path, settings.BASE_DIR), 'templates')
         def recurse(folder):
-            for filename in os.listdir(os.path.join(template_root, folder)):
-                if filename.startswith('__'):
-                    continue
-                filerel = os.path.join(folder, filename)
-                filepath = os.path.join(os.path.join(template_root, filerel))
-                if os.path.isdir(filepath):
-                    recurse(filerel)
+            subdirs = []
+            if os.path.exists(folder):
+                for filename in os.listdir(folder):
+                    if filename.startswith('__'):
+                        continue
+                    filerel = os.path.join(folder, filename)
+                    if os.path.isdir(filerel):
+                        subdirs.append(filerel)
 
-                elif os.path.isfile(filepath):
-                    scripts = self.template_scripts(config, filerel)
-                    key = '{}/{}'.format(config.name, os.path.splitext(filerel)[0])
-                    if len(scripts) > 0:
-                        script_map[key] = scripts
-                        self.message('\t{}: {}'.format(key, scripts), 3)
-                    else:
-                        self.message('\t{}: none found'.format(key), 3)
-        recurse('')
+                    elif os.path.isfile(filerel):
+                        template_name = os.path.relpath(filerel, template_root)
+                        scripts = self.template_scripts(config, template_name)
+                        key = '{}/{}'.format(config.name, os.path.splitext(template_name)[0])
+                        if len(scripts) > 0:
+                            script_map[key] = scripts
+                            self.message('\t{}: {}'.format(key, scripts), 3)
+                        else:
+                            self.message('\t{}: none found'.format(key), 3)
+            for subdir in subdirs:
+                recurse(subdir)
+
+        recurse(template_root)
         return script_map
 
 
@@ -190,14 +178,14 @@ class Command(BaseCommand):
         because that class creates the 'enabled' list of provider instances, and each
         provider instance has a url.
         '''
-        template_obj = get_dmp_instance().get_template_loader(config, create=True).get_mako_template(template_name, force=True)
+        dmp = django_apps.get_app_config('django_mako_plus')
+        template_obj = dmp.engine.get_template_loader(config, create=True).get_mako_template(template_name, force=True)
         mako_context = create_mako_context(template_obj)
         inner_run = ProviderRun(mako_context['self'], factories=self.factories)
         inner_run.run()
         scripts = []
         for data in inner_run.column_data:
-            for provider in data.get('enabled', []):
-                if getattr(provider, 'url') is not None:
-                    url = provider.url.split('?', 1)[0]
-                    scripts.append(os.path.relpath(url, settings.BASE_DIR))
+            for provider in data.get('enabled', []):    # if file doesn't exist, the provider won't be enabled
+                if hasattr(provider, 'filepath'):       # providers used to collect for webpack must have a .filepath property
+                    scripts.append(provider.filepath)   # the absolute path to the file (see providers/static_links.py)
         return scripts
