@@ -1,3 +1,4 @@
+import os, os.path
 
 
 
@@ -38,10 +39,19 @@ class DMPCommandMixIn(object):
 
     def execute(self, *args, **options):
         '''Placing this in execute because then subclass handle() don't have to call super'''
+        if options['verbose']:
+            options['verbosity'] = 3
+        if options['quiet']:
+            options['verbosity'] = 0
         self.verbosity = options.get('verbosity', 1)
         super().execute(*args, **options)
 
 
+    def get_dmp_path(self):
+        '''Returns the absolute path to DMP.  Apps do not have to be loaded yet'''
+        return os.path.dirname(os.path.dirname(__file__))
+
+
     def message(self, msg='', level=1, tab=0):
         '''Print a message to the console'''
         if self.verbosity >= level:
