@@ -7,35 +7,14 @@ import os, os.path
 import collections
 import zlib
 import re
+from importlib import import_module
 
 
-# this is populated with the dictionary of options in engine.py when
-# Django initializes the template engine
-DMP_OPTIONS = {}
-
-# the key for the DMP singleton engine instance (stored in DMP_OPTIONS by engine.py)
-DMP_INSTANCE_KEY = 'django_mako_plus_instance'
 
 # set up the logger
 import logging
 log = logging.getLogger('django_mako_plus')
 
-################################################################
-###   DMP instance and apps
-
-def get_dmp_instance():
-    '''
-    Retrieves the DMP template engine instance.
-    '''
-    try:
-        return DMP_OPTIONS[DMP_INSTANCE_KEY]
-    except KeyError:
-        raise ImproperlyConfigured('The Django Mako Plus template engine did not initialize correctly.  Check your logs for previous errors that may have caused initialization to fail, and check that DMP is set correctly in settings.py.')
-
-
-def get_dmp_path():
-    return os.path.dirname(os.path.abspath(__file__))
-
 
 
 ################################################################
@@ -64,6 +43,23 @@ class URLParamList(list):
 ##########################################
 ###   Utilities
 
+def import_qualified(name):
+    '''
+    Imports a fully-qualified name from a module:
+
+        cls = import_qualified('homepage.views.index.MyForm')
+
+    Raises an ImportError if it can't be ipmorted.
+    '''
+    parts = name.rsplit('.', 1)
+    if len(parts) != 2:
+        raise ImportError('Invalid fully-qualified name: {}'.format(name))
+    try:
+        return getattr(import_module(parts[0]), parts[1])
+    except AttributeError:
+        raise ImportError('{} not found in module {}'.format(parts[1], parts[0]))
+
+
 def merge_dicts(*dicts):
     '''
     Merges an arbitrary number of dicts, starting
@@ -72,7 +68,8 @@ def merge_dicts(*dicts):
     '''
     merged = {}
     for d in dicts:
-        merged.update(d)
+        if d:
+            merged.update(d)
     return merged
 
 
